@@ -29,6 +29,10 @@ def format_iso_date(value: Optional[date]) -> Optional[str]:
     return value.strftime("%Y-%m-%d") if value else None
 
 
+def format_iso_datetime(value: Optional[datetime]) -> Optional[str]:
+    return value.strftime("%Y-%m-%dT%H:%M:%SZ") if value else None
+
+
 def as_decimal(value: Optional[Union[float, str]]) -> Optional[Decimal]:
     try:
         return Decimal(str(value)) if value is not None else None
@@ -45,3 +49,19 @@ def parse_datetime(value: Optional[str]) -> Optional[datetime]:
         return None
 
     return result.replace(tzinfo=timezone.utc)
+
+
+def snake_to_camel_case(input_string: str) -> str:
+    """Function to reformat input string from snake_case to CamelCase.
+
+    Args:
+        input_string: The inpyt string.
+
+    Returns:
+        Input string converted to CamelCase.
+    """
+    temp = input_string.split('_')
+    for i, s in enumerate(temp):
+        temp[i] = s[0].upper() + s[1:]
+        result = temp[0] + ''.join(x.title() for x in temp[1:])
+    return result
