@@ -23,18 +23,27 @@ def _to_snake_case(s: str) -> str:
     return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s).lower()
 
 
-def _to_camel_case(s: str) -> str:
+def _to_camel_case(s: str,
+                   rename_keys: Optional[Dict[str, str]] = None) -> str:
     """Transforms a string from snake_case to camel_case.
 
     Args:
         s: The string to transform
+        rename_keys: Key names to transform explicitly to the desired
+            target string when the default output is not adequate.
 
     Returns:
         The transformed string
     """
     _to_camelcase = s.split('_')
     _to_camelcase = [word.capitalize() for word in _to_camelcase]
-    return ''.join(_to_camelcase)
+    result = ''.join(_to_camelcase)
+
+    if rename_keys:
+        if s in rename_keys:
+            result = rename_keys[s]
+
+    return result
 
 
 def _parse_class(value: Any, cls: Type[ParsableClass]) \
